summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMichael5 Chen1 <michael5_chen1@pegatron.corp-partner.google.com>2022-12-09 16:57:58 +0800
committerChromeos LUCI <chromeos-scoped@luci-project-accounts.iam.gserviceaccount.com>2022-12-13 07:42:15 +0000
commitef431ade168d5ceeab3176595d2f2e5f6ca2ae23 (patch)
tree579d7cba2b94de1723f0bab85e589c97e1dd2c0b
parentb1f1b67b40cbd16d9bf6e76c3bf1eceb125c6071 (diff)
downloadchrome-ec-ef431ade168d5ceeab3176595d2f2e5f6ca2ae23.tar.gz
marasov: modify fw_config setting
Modify FW_CONFIG setting. BUG=b:256374573 BRANCH=none TEST=make BOARD=marasov Change-Id: I4b0c174048abb331fa3c96388f9026769e4e0ae4 Signed-off-by: Michael5 Chen1 <michael5_chen1@pegatron.corp-partner.google.com> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/4090782 Commit-Queue: Kyle Lin <kylelinck@google.com> Code-Coverage: Zoss <zoss-cl-coverage@prod.google.com> Reviewed-by: Kyle Lin <kylelinck@google.com>
-rw-r--r--board/marasov/fw_config.c11
-rw-r--r--board/marasov/fw_config.h31
2 files changed, 18 insertions, 24 deletions
diff --git a/board/marasov/fw_config.c b/board/marasov/fw_config.c
index 375f5e965b..39c5488331 100644
--- a/board/marasov/fw_config.c
+++ b/board/marasov/fw_config.c
@@ -12,15 +12,14 @@
#define CPRINTS(format, args...) cprints(CC_SYSTEM, format, ##args)
-static union brya_cbi_fw_config fw_config;
+static union marasov_cbi_fw_config fw_config;
BUILD_ASSERT(sizeof(fw_config) == sizeof(uint32_t));
/*
* FW_CONFIG defaults for brya if the CBI.FW_CONFIG data is not
* initialized.
*/
-static const union brya_cbi_fw_config fw_config_defaults = {
- .usb_db = DB_USB3_PS8815,
+static const union marasov_cbi_fw_config fw_config_defaults = {
.kb_bl = KEYBOARD_BACKLIGHT_ENABLED,
};
@@ -35,12 +34,12 @@ void board_init_fw_config(void)
}
}
-union brya_cbi_fw_config get_fw_config(void)
+union marasov_cbi_fw_config get_fw_config(void)
{
return fw_config;
}
-enum ec_cfg_usb_db_type ec_cfg_usb_db_type(void)
+enum ec_cfg_keyboard_backlight_type ec_cfg_kb_bl_type(void)
{
- return fw_config.usb_db;
+ return fw_config.kb_bl;
}
diff --git a/board/marasov/fw_config.h b/board/marasov/fw_config.h
index 906e61fe7e..e208e80ca0 100644
--- a/board/marasov/fw_config.h
+++ b/board/marasov/fw_config.h
@@ -3,34 +3,29 @@
* found in the LICENSE file.
*/
-#ifndef __BOARD_BRYA_FW_CONFIG_H_
-#define __BOARD_BRYA_FW_CONFIG_H_
+#ifndef __BOARD_MARASOV_FW_CONFIG_H_
+#define __BOARD_MARASOV_FW_CONFIG_H_
#include <stdint.h>
/****************************************************************************
* CBI FW_CONFIG layout for Brya board.
*
* Source of truth is the project/brya/brya/config.star configuration file.
*/
-enum ec_cfg_usb_db_type {
- DB_USB3_PS8815 = 0,
-};
-
enum ec_cfg_keyboard_backlight_type {
KEYBOARD_BACKLIGHT_DISABLED = 0,
KEYBOARD_BACKLIGHT_ENABLED = 1
};
-union brya_cbi_fw_config {
+union marasov_cbi_fw_config {
struct {
- enum ec_cfg_usb_db_type usb_db : 4;
- uint32_t sd_db : 2;
- uint32_t lte_db : 1;
enum ec_cfg_keyboard_backlight_type kb_bl : 1;
uint32_t audio : 3;
- uint32_t reserved_1 : 21;
+ uint32_t ufc : 1;
+ uint32_t reserved_1 : 25;
+ uint32_t storage : 2;
};
uint32_t raw_value;
};
@@ -40,13 +35,13 @@ union brya_cbi_fw_config {
*
* @return the FW_CONFIG for the board.
*/
-union brya_cbi_fw_config get_fw_config(void);
+union marasov_cbi_fw_config get_fw_config(void);
/**
* Get the USB daughter board type from FW_CONFIG.
*
- * @return the USB daughter board type.
+ * @return the keyboard backlight type.
*/
-enum ec_cfg_usb_db_type ec_cfg_usb_db_type(void);
+enum ec_cfg_keyboard_backlight_type ec_cfg_kb_bl_type(void);
-#endif /* __BOARD_BRYA_FW_CONFIG_H_ */
+#endif /* __BOARD_MARASOV_FW_CONFIG_H_ */
@@ -3,34 +3,29 @@
#include <stdint.h>
/****************************************************************************
- * CBI FW_CONFIG layout for Brya board.
+ * CBI FW_CONFIG layout for marasov board.
*
@@ -3,34 +3,29 @@
*
- * Source of truth is the project/brya/brya/config.star configuration file.
+ * Source of truth is the project/brya/marasov/config.star configuration file.
*/
@@ -40,13 +35,13 @@ union brya_cbi_fw_config {
/**
- * Get the USB daughter board type from FW_CONFIG.
+ * Get the keyboard backlight type from FW_CONFIG.
*